@@ -1,5 +1,5 @@
 package Exception::DB::NoFieldsAvailable;
-$Exception::DB::NoFieldsAvailable::VERSION = '0.020';
+$Exception::DB::NoFieldsAvailable::VERSION = '0.021';
 use base qw(Exception::DB);
 
 =head1 Name
@@ -13,7 +13,7 @@ Base class for DB queries.
 =cut
 
 package QBit::Application::Model::DB::Query;
-$QBit::Application::Model::DB::Query::VERSION = '0.020';
+$QBit::Application::Model::DB::Query::VERSION = '0.021';
 use qbit;
 
 use base qw(QBit::Application::Model::DB::Class);
@@ -292,6 +292,42 @@ sub group_by {
     return $self;
 }
 
+=head2 having
+
+B<Arguments:>
+
+=over
+
+=item *
+
+B<$expression>
+
+=back
+
+B<Return values:>
+
+=over
+
+=item *
+
+B<$query> - object
+
+=back
+
+B<Example:>
+
+  my $query_with_having = $query->having([cnt => '>=' => \100]);
+
+=cut
+
+sub having {
+    my ($self, $expression) = @_;
+
+    $self->{'__HAVING__'} = $expression;
+
+    return $self;
+}
+
 =head2 order_by
 
 B<Arguments:>
@@ -700,6 +736,16 @@ sub get_sql_with_data {
     $sql .= "\n${offset}GROUP BY " . CORE::join(', ', map {$self->quote_identifier($_)} @{$self->{'__GROUP_BY__'}})
       if exists($self->{'__GROUP_BY__'});
 
+    if (exists($self->{'__HAVING__'})) {
+        local $self->{'without_check_fields'} = {};
+        local $self->{'without_table_alias'}  = TRUE;
+
+        my ($having, @having_data) = $self->_field_to_sql(undef, $self->{'__HAVING__'}, $select_query_table);
+
+        $sql .= "\n${offset}HAVING $having";
+        push(@sql_data, @having_data) if @having_data;
+    }
+
     $sql .= $self->_after_group_by();
 
     $sql .=
@@ -870,7 +916,9 @@ sub _field_to_sql {
 
     } elsif (!ref($expr) && $expr eq '') {
         # {field_name => ''}
-        my $field = $cur_query_table->{'table'}->_fields_hs()->{$alias}
+        my $field =
+             $cur_query_table->{'table'}->_fields_hs()->{$alias}
+          || $self->{'without_check_fields'}
           || throw Exception::BadArguments gettext('Table "%s" has not field "%s"', $cur_query_table->{'table'}->name,
             $alias);
 
@@ -884,13 +932,15 @@ sub _field_to_sql {
 
     } elsif (!ref($expr)) {
         # {new_field_name => 'field_name'}
-        my $field = $cur_query_table->{'table'}->_fields_hs()->{$expr}
+        my $field =
+             $cur_query_table->{'table'}->_fields_hs()->{$expr}
+          || $self->{'without_check_fields'}
           || throw Exception::BadArguments gettext('Table "%s" has not field "%s"', $cur_query_table->{'table'}->name,
             $expr);
 
         return (
             map {
-                  $self->_get_table_alias($cur_query_table)
+                    $self->_get_table_alias($cur_query_table)
                   . $self->quote_identifier($expr . $_)
                   . (
                     defined($alias)
@@ -909,7 +959,9 @@ sub _field_to_sql {
     {
         # {alias => {field_name => 'tbl_alias'}} {alias => {field_name => $...db->tbl}}
         my $query_table = $self->_get_table([%$expr]->[1]);
-        my $field       = $query_table->{'table'}->_fields_hs()->{[%$expr]->[0]}
+        my $field =
+             $query_table->{'table'}->_fields_hs()->{[%$expr]->[0]}
+          || $self->{'without_check_fields'}
           || throw Exception::BadArguments gettext('Table "%s" has not field "%s"', $query_table->{'table'}->name,
             [%$expr]->[0]);
 
@@ -1050,7 +1102,7 @@ sub _field_to_sql {
 sub _get_table_alias {
     my ($self, $table) = @_;
 
-    return $self->quote_identifier($self->_table_alias($table)) . '.';
+    return $self->{'without_table_alias'} ? '' : $self->quote_identifier($self->_table_alias($table)) . '.';
 }
 
 TRUE;
